package pps.core.base.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import pps.core.base.entity.BasePowerLinePlantEnt;
import pps.core.base.entity.BasePowerLinePlantView;
import pps.core.base.mapper.BasePowerLinePlantMapper;
import pps.core.base.mapper.BasePowerLinePlantViewMapper;
import pps.core.base.service.data.base_power_line_plant.*;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.base.data.CustomQueryInput;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XPageResult;
import xstartup.data.XServiceResult;
import xstartup.data.XSingleResult;
import xstartup.error.XError;
import xstartup.feature.api.annotation.XApiAnonymous;
import xstartup.feature.api.annotation.XApiGet;
import xstartup.feature.api.annotation.XApiPost;
import xstartup.feature.mybatis.helper.XMapperHelper;

import java.util.List;

@XService
public class BasePowerLinePlantService {
    @XApiAnonymous
    @XApiPost
    public XServiceResult createBasePowerLinePlant(XContext context, CreateBasePowerLinePlantInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        BasePowerLinePlantEnt entity = new BasePowerLinePlantEnt();
        XCopyUtils.copyObject(input, entity);
        mapper.insert(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult updateBasePowerLinePlant(XContext context, UpdateBasePowerLinePlantInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        QueryWrapper<BasePowerLinePlantEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLinePlantEnt::getId, input.getId());
        BasePowerLinePlantEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        XCopyUtils.copyObject(input, entity);
        mapper.updateById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiPost
    public XServiceResult deleteBasePowerLinePlant(XContext context, DeleteBasePowerLinePlantInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        QueryWrapper<BasePowerLinePlantEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLinePlantEnt::getId, input.getId());
        BasePowerLinePlantEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XServiceResult.error(context, XError.NotFound);
        }
        mapper.deleteById(entity);
        return XServiceResult.OK;
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetBasePowerLinePlantOutput> getBasePowerLinePlant(XContext context, GetBasePowerLinePlantInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        QueryWrapper<BasePowerLinePlantEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BasePowerLinePlantEnt::getId, input.getId());
        BasePowerLinePlantEnt entity = mapper.selectOne(queryWrapper);
        if (entity == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetBasePowerLinePlantOutput output = new GetBasePowerLinePlantOutput();
        XCopyUtils.copyObject(entity, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLinePlantOutput> queryBasePowerLinePlant(XContext context, QueryBasePowerLinePlantInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        QueryWrapper<BasePowerLinePlantEnt> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().like(BasePowerLinePlantEnt::getId, input.getId())
                .eq(BasePowerLinePlantEnt::getIsDeleted, input.getIsDeleted())
                .like(BasePowerLinePlantEnt::getCreateById, input.getCreateById())
                .like(BasePowerLinePlantEnt::getCreateByName, input.getCreateByName())
                .eq(BasePowerLinePlantEnt::getCreateTime, input.getCreateTime())
                .like(BasePowerLinePlantEnt::getModifyById, input.getModifyById())
                .like(BasePowerLinePlantEnt::getModifyByName, input.getModifyByName())
                .eq(BasePowerLinePlantEnt::getModifyTime, input.getModifyTime())
                .like(BasePowerLinePlantEnt::getLineId, input.getLineId())
                .like(BasePowerLinePlantEnt::getPlantId, input.getPlantId());
        return XMapperHelper.query(mapper, input, queryWrapper, QueryBasePowerLinePlantOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLinePlantOutput> dynamicQueryBasePowerLinePlant(XContext context, CustomQueryInput input) {
        BasePowerLinePlantMapper mapper = context.getBean(BasePowerLinePlantMapper.class);
        return XMapperHelper.query(mapper, input, BasePowerLinePlantEnt.class, QueryBasePowerLinePlantOutput.class);
    }

    @XApiAnonymous
    @XApiGet
    public XSingleResult<GetBasePowerLinePlantViewOutput> getBasePowerLinePlantView(XContext context, GetBasePowerLinePlantViewInput input) {
        BasePowerLinePlantViewMapper mapper = context.getBean(BasePowerLinePlantViewMapper.class);
        BasePowerLinePlantView record = new BasePowerLinePlantView();
        XCopyUtils.copyObject(input, record);
        BasePowerLinePlantView view = mapper.selectOne(record);
        if (view == null) {
            return XSingleResult.error(context, XError.NotFound);
        }
        GetBasePowerLinePlantViewOutput output = new GetBasePowerLinePlantViewOutput();
        XCopyUtils.copyObject(view, output);
        return XSingleResult.success(output);
    }

    @XApiAnonymous
    @XApiGet
    public XPageResult<QueryBasePowerLinePlantViewOutput> queryBasePowerLinePlantView(XContext context, QueryBasePowerLinePlantViewInput input) {
        BasePowerLinePlantViewMapper mapper = context.getBean(BasePowerLinePlantViewMapper.class);
        BasePowerLinePlantView record = new BasePowerLinePlantView();
        XCopyUtils.copyObject(input, record);
        PageHelper.startPage(input.getPage(), input.getLimit());
        List<BasePowerLinePlantView> list = mapper.selectList(record);
        PageInfo<BasePowerLinePlantView> pageInfo = new PageInfo<>(list);
        List<QueryBasePowerLinePlantViewOutput> outputs = XCopyUtils.copyNewList(pageInfo.getList(), QueryBasePowerLinePlantViewOutput.class);
        return XPageResult.success(outputs, input, pageInfo.getTotal());
    }

}
